
namespace BooCompiler.Tests
{
	using NUnit.Framework;
	using Boo.Lang.Compiler;

	[TestFixture]
	public class CompilerErrorsTestFixture : AbstractCompilerErrorsTestFixture
	{

		[Test]
		public void BCE0000_1()
		{
			RunCompilerTestCase(@"BCE0000-1.boo");
		}
		
		[Test]
		public void BCE0004_1()
		{
			RunCompilerTestCase(@"BCE0004-1.boo");
		}
		
		[Test]
		public void BCE0004_2()
		{
			RunCompilerTestCase(@"BCE0004-2.boo");
		}
		
		[Test]
		public void BCE0005_1()
		{
			RunCompilerTestCase(@"BCE0005-1.boo");
		}
		
		[Test]
		public void BCE0005_2()
		{
			RunCompilerTestCase(@"BCE0005-2.boo");
		}
		
		[Test]
		public void BCE0006_1()
		{
			RunCompilerTestCase(@"BCE0006-1.boo");
		}
		
		[Test]
		public void BCE0017_1()
		{
			RunCompilerTestCase(@"BCE0017-1.boo");
		}
		
		[Test]
		public void BCE0017_2()
		{
			RunCompilerTestCase(@"BCE0017-2.boo");
		}
		
		[Test]
		public void BCE0017_3()
		{
			RunCompilerTestCase(@"BCE0017-3.boo");
		}
		
		[Test]
		public void BCE0018_1()
		{
			RunCompilerTestCase(@"BCE0018-1.boo");
		}
		
		[Test]
		public void BCE0018_2()
		{
			RunCompilerTestCase(@"BCE0018-2.boo");
		}
		
		[Test]
		public void BCE0018_3()
		{
			RunCompilerTestCase(@"BCE0018-3.boo");
		}
		
		[Test]
		public void BCE0019_1()
		{
			RunCompilerTestCase(@"BCE0019-1.boo");
		}
		
		[Test]
		public void BCE0019_2()
		{
			RunCompilerTestCase(@"BCE0019-2.boo");
		}
		
		[Test]
		public void BCE0020_1()
		{
			RunCompilerTestCase(@"BCE0020-1.boo");
		}
		
		[Test]
		public void BCE0020_2()
		{
			RunCompilerTestCase(@"BCE0020-2.boo");
		}
		
		[Test]
		public void BCE0020_3()
		{
			RunCompilerTestCase(@"BCE0020-3.boo");
		}
		
		[Test]
		public void BCE0021_1()
		{
			RunCompilerTestCase(@"BCE0021-1.boo");
		}
		
		[Test]
		public void BCE0022_1()
		{
			RunCompilerTestCase(@"BCE0022-1.boo");
		}
		
		[Test]
		public void BCE0022_10()
		{
			RunCompilerTestCase(@"BCE0022-10.boo");
		}
		
		[Test]
		public void BCE0022_11()
		{
			RunCompilerTestCase(@"BCE0022-11.boo");
		}
		
		[Test]
		public void BCE0022_2()
		{
			RunCompilerTestCase(@"BCE0022-2.boo");
		}
		
		[Test]
		public void BCE0022_3()
		{
			RunCompilerTestCase(@"BCE0022-3.boo");
		}
		
		[Test]
		public void BCE0022_4()
		{
			RunCompilerTestCase(@"BCE0022-4.boo");
		}
		
		[Test]
		public void BCE0022_5()
		{
			RunCompilerTestCase(@"BCE0022-5.boo");
		}
		
		[Test]
		public void BCE0022_6()
		{
			RunCompilerTestCase(@"BCE0022-6.boo");
		}
		
		[Test]
		public void BCE0022_7()
		{
			RunCompilerTestCase(@"BCE0022-7.boo");
		}
		
		[Test]
		public void BCE0022_8()
		{
			RunCompilerTestCase(@"BCE0022-8.boo");
		}
		
		[Test]
		public void BCE0022_9()
		{
			RunCompilerTestCase(@"BCE0022-9.boo");
		}
		
		[Test]
		public void BCE0023_1()
		{
			RunCompilerTestCase(@"BCE0023-1.boo");
		}
		
		[Test]
		public void BCE0024_1()
		{
			RunCompilerTestCase(@"BCE0024-1.boo");
		}
		
		[Test]
		public void BCE0024_2()
		{
			RunCompilerTestCase(@"BCE0024-2.boo");
		}
		
		[Test]
		public void BCE0024_3()
		{
			RunCompilerTestCase(@"BCE0024-3.boo");
		}
		
		[Test]
		public void BCE0024_4()
		{
			RunCompilerTestCase(@"BCE0024-4.boo");
		}
		
		[Test]
		public void BCE0032_1()
		{
			RunCompilerTestCase(@"BCE0032-1.boo");
		}
		
		[Test]
		public void BCE0035_1()
		{
			RunCompilerTestCase(@"BCE0035-1.boo");
		}
		
		[Test]
		public void BCE0035_2()
		{
			RunCompilerTestCase(@"BCE0035-2.boo");
		}
		
		[Test]
		public void BCE0035_3()
		{
			RunCompilerTestCase(@"BCE0035-3.boo");
		}
		
		[Test]
		public void BCE0046_1()
		{
			RunCompilerTestCase(@"BCE0046-1.boo");
		}
		
		[Test]
		public void BCE0047_1()
		{
			RunCompilerTestCase(@"BCE0047-1.boo");
		}
		
		[Test]
		public void BCE0047_2()
		{
			RunCompilerTestCase(@"BCE0047-2.boo");
		}
		
		[Test]
		public void BCE0049_1()
		{
			RunCompilerTestCase(@"BCE0049-1.boo");
		}
		
		[Test]
		public void BCE0051_1()
		{
			RunCompilerTestCase(@"BCE0051-1.boo");
		}
		
		[Test]
		public void BCE0051_2()
		{
			RunCompilerTestCase(@"BCE0051-2.boo");
		}
		
		[Test]
		public void BCE0053_1()
		{
			RunCompilerTestCase(@"BCE0053-1.boo");
		}
		
		[Test]
		public void BCE0053_2()
		{
			RunCompilerTestCase(@"BCE0053-2.boo");
		}
		
		[Test]
		public void BCE0053_3()
		{
			RunCompilerTestCase(@"BCE0053-3.boo");
		}
		
		[Test]
		public void BCE0057_1()
		{
			RunCompilerTestCase(@"BCE0057-1.boo");
		}
		
		[Test]
		public void BCE0058_1()
		{
			RunCompilerTestCase(@"BCE0058-1.boo");
		}
		
		[Test]
		public void BCE0060_1()
		{
			RunCompilerTestCase(@"BCE0060-1.boo");
		}
		
		[Test]
		public void BCE0060_2()
		{
			RunCompilerTestCase(@"BCE0060-2.boo");
		}
		
		[Test]
		public void BCE0061_1()
		{
			RunCompilerTestCase(@"BCE0061-1.boo");
		}
		
		[Test]
		public void BCE0063_1()
		{
			RunCompilerTestCase(@"BCE0063-1.boo");
		}
		
		[Test]
		public void BCE0063_2()
		{
			RunCompilerTestCase(@"BCE0063-2.boo");
		}
		
		[Test]
		public void BCE0063_3()
		{
			RunCompilerTestCase(@"BCE0063-3.boo");
		}
		
		[Test]
		public void BCE0063_4()
		{
			RunCompilerTestCase(@"BCE0063-4.boo");
		}
		
		[Test]
		public void BCE0065_1()
		{
			RunCompilerTestCase(@"BCE0065-1.boo");
		}
		
		[Test]
		public void BCE0067_1()
		{
			RunCompilerTestCase(@"BCE0067-1.boo");
		}
		
		[Test]
		public void BCE0067_2()
		{
			RunCompilerTestCase(@"BCE0067-2.boo");
		}
		
		[Test]
		public void BCE0067_3()
		{
			RunCompilerTestCase(@"BCE0067-3.boo");
		}
		
		[Test]
		public void BCE0070_1()
		{
			RunCompilerTestCase(@"BCE0070-1.boo");
		}
		
		[Test]
		public void BCE0070_2()
		{
			RunCompilerTestCase(@"BCE0070-2.boo");
		}
		
		[Test]
		public void BCE0070_3()
		{
			RunCompilerTestCase(@"BCE0070-3.boo");
		}
		
		[Test]
		public void BCE0071_1()
		{
			RunCompilerTestCase(@"BCE0071-1.boo");
		}
		
		[Test]
		public void BCE0071_2()
		{
			RunCompilerTestCase(@"BCE0071-2.boo");
		}
		
		[Test]
		public void BCE0072_1()
		{
			RunCompilerTestCase(@"BCE0072-1.boo");
		}
		
		[Test]
		public void BCE0072_2()
		{
			RunCompilerTestCase(@"BCE0072-2.boo");
		}
		
		[Test]
		public void BCE0073_1()
		{
			RunCompilerTestCase(@"BCE0073-1.boo");
		}
		
		[Test]
		public void BCE0079_1()
		{
			RunCompilerTestCase(@"BCE0079-1.boo");
		}
		
		[Test]
		public void BCE0080_1()
		{
			RunCompilerTestCase(@"BCE0080-1.boo");
		}
		
		[Test]
		public void BCE0081_1()
		{
			RunCompilerTestCase(@"BCE0081-1.boo");
		}
		
		[Test]
		public void BCE0081_2()
		{
			RunCompilerTestCase(@"BCE0081-2.boo");
		}
		
		[Test]
		public void BCE0081_3()
		{
			RunCompilerTestCase(@"BCE0081-3.boo");
		}
		
		[Test]
		public void BCE0081_4()
		{
			RunCompilerTestCase(@"BCE0081-4.boo");
		}
		
		[Test]
		public void BCE0081_5()
		{
			RunCompilerTestCase(@"BCE0081-5.boo");
		}
		
		[Test]
		public void BCE0082_1()
		{
			RunCompilerTestCase(@"BCE0082-1.boo");
		}
		
		[Test]
		public void BCE0083_1()
		{
			RunCompilerTestCase(@"BCE0083-1.boo");
		}
		
		[Test]
		public void BCE0084_1()
		{
			RunCompilerTestCase(@"BCE0084-1.boo");
		}
		
		[Test]
		public void BCE0085_1()
		{
			RunCompilerTestCase(@"BCE0085-1.boo");
		}
		
		[Test]
		public void BCE0085_3()
		{
			RunCompilerTestCase(@"BCE0085-3.boo");
		}
		
		[Test]
		public void BCE0086_1()
		{
			RunCompilerTestCase(@"BCE0086-1.boo");
		}
		
		[Test]
		public void BCE0087_1()
		{
			RunCompilerTestCase(@"BCE0087-1.boo");
		}
		
		[Test]
		public void BCE0088_1()
		{
			RunCompilerTestCase(@"BCE0088-1.boo");
		}
		
		[Test]
		public void BCE0089_1()
		{
			RunCompilerTestCase(@"BCE0089-1.boo");
		}
		
		[Test]
		public void BCE0089_10()
		{
			RunCompilerTestCase(@"BCE0089-10.boo");
		}
		
		[Test]
		public void BCE0089_11()
		{
			RunCompilerTestCase(@"BCE0089-11.boo");
		}
		
		[Test]
		public void BCE0089_12()
		{
			RunCompilerTestCase(@"BCE0089-12.boo");
		}
		
		[Test]
		public void BCE0089_13()
		{
			RunCompilerTestCase(@"BCE0089-13.boo");
		}
		
		[Test]
		public void BCE0089_2()
		{
			RunCompilerTestCase(@"BCE0089-2.boo");
		}
		
		[Test]
		public void BCE0089_3()
		{
			RunCompilerTestCase(@"BCE0089-3.boo");
		}
		
		[Test]
		public void BCE0089_4()
		{
			RunCompilerTestCase(@"BCE0089-4.boo");
		}
		
		[Test]
		public void BCE0089_5()
		{
			RunCompilerTestCase(@"BCE0089-5.boo");
		}
		
		[Test]
		public void BCE0089_6()
		{
			RunCompilerTestCase(@"BCE0089-6.boo");
		}
		
		[Test]
		public void BCE0089_7()
		{
			RunCompilerTestCase(@"BCE0089-7.boo");
		}
		
		[Test]
		public void BCE0089_8()
		{
			RunCompilerTestCase(@"BCE0089-8.boo");
		}
		
		[Test]
		public void BCE0089_9()
		{
			RunCompilerTestCase(@"BCE0089-9.boo");
		}
		
		[Test]
		public void BCE0090_1()
		{
			RunCompilerTestCase(@"BCE0090-1.boo");
		}
		
		[Test]
		public void BCE0090_2()
		{
			RunCompilerTestCase(@"BCE0090-2.boo");
		}
		
		[Test]
		public void BCE0091_1()
		{
			RunCompilerTestCase(@"BCE0091-1.boo");
		}
		
		[Test]
		public void BCE0092_1()
		{
			RunCompilerTestCase(@"BCE0092-1.boo");
		}
		
		[Test]
		public void BCE0093_1()
		{
			RunCompilerTestCase(@"BCE0093-1.boo");
		}
		
		[Test]
		public void BCE0093_2()
		{
			RunCompilerTestCase(@"BCE0093-2.boo");
		}
		
		[Test]
		public void BCE0094_1()
		{
			RunCompilerTestCase(@"BCE0094-1.boo");
		}
		
		[Test]
		public void BCE0095_1()
		{
			RunCompilerTestCase(@"BCE0095-1.boo");
		}
		
		[Test]
		public void BCE0095_2()
		{
			RunCompilerTestCase(@"BCE0095-2.boo");
		}
		
		[Test]
		public void BCE0096_1()
		{
			RunCompilerTestCase(@"BCE0096-1.boo");
		}
		
		[Test]
		public void BCE0097_1()
		{
			RunCompilerTestCase(@"BCE0097-1.boo");
		}
		
		[Test]
		public void BCE0097_2()
		{
			RunCompilerTestCase(@"BCE0097-2.boo");
		}
		
		[Test]
		public void BCE0099_1()
		{
			RunCompilerTestCase(@"BCE0099-1.boo");
		}
		
		[Test]
		public void BCE0099_2()
		{
			RunCompilerTestCase(@"BCE0099-2.boo");
		}
		
		[Test]
		public void BCE0100_1()
		{
			RunCompilerTestCase(@"BCE0100-1.boo");
		}
		
		[Test]
		public void BCE0101_1()
		{
			RunCompilerTestCase(@"BCE0101-1.boo");
		}
		
		[Test]
		public void BCE0101_2()
		{
			RunCompilerTestCase(@"BCE0101-2.boo");
		}
		
		[Test]
		public void BCE0102_1()
		{
			RunCompilerTestCase(@"BCE0102-1.boo");
		}
		
		[Test]
		public void BCE0103_1()
		{
			RunCompilerTestCase(@"BCE0103-1.boo");
		}
		
		[Test]
		public void BCE0103_2()
		{
			RunCompilerTestCase(@"BCE0103-2.boo");
		}
		
		[Test]
		public void BCE0103_3()
		{
			RunCompilerTestCase(@"BCE0103-3.boo");
		}
		
		[Test]
		public void BCE0104_1()
		{
			RunCompilerTestCase(@"BCE0104-1.boo");
		}
		
		[Test]
		public void BCE0105_1()
		{
			RunCompilerTestCase(@"BCE0105-1.boo");
		}
		
		[Test]
		public void BCE0107_1()
		{
			RunCompilerTestCase(@"BCE0107-1.boo");
		}
		
		[Test]
		public void BCE0108_1()
		{
			RunCompilerTestCase(@"BCE0108-1.boo");
		}
		
		[Test]
		public void BCE0111_1()
		{
			RunCompilerTestCase(@"BCE0111-1.boo");
		}
		
		[Test]
		public void BCE0112_1()
		{
			RunCompilerTestCase(@"BCE0112-1.boo");
		}
		
		[Test]
		public void BCE0114_1()
		{
			RunCompilerTestCase(@"BCE0114-1.boo");
		}
		
		[Test]
		public void BCE0115_1()
		{
			RunCompilerTestCase(@"BCE0115-1.boo");
		}
		
		[Test]
		public void BCE0116_1()
		{
			RunCompilerTestCase(@"BCE0116-1.boo");
		}
		
		[Test]
		public void BCE0117_1()
		{
			RunCompilerTestCase(@"BCE0117-1.boo");
		}
		
		[Test]
		public void BCE0120_1()
		{
			RunCompilerTestCase(@"BCE0120-1.boo");
		}
		
		[Test]
		public void BCE0120_2()
		{
			RunCompilerTestCase(@"BCE0120-2.boo");
		}
		
		[Test]
		public void BCE0120_3()
		{
			RunCompilerTestCase(@"BCE0120-3.boo");
		}
		
		[Test]
		public void BCE0120_4()
		{
			RunCompilerTestCase(@"BCE0120-4.boo");
		}
		
		[Test]
		public void BCE0121_1()
		{
			RunCompilerTestCase(@"BCE0121-1.boo");
		}
		
		[Test]
		public void BCE0122_1()
		{
			RunCompilerTestCase(@"BCE0122-1.boo");
		}
		
		[Test]
		public void BCE0123_1()
		{
			RunCompilerTestCase(@"BCE0123-1.boo");
		}
		
		[Test]
		public void BCE0124_1()
		{
			RunCompilerTestCase(@"BCE0124-1.boo");
		}
		
		[Test]
		public void BCE0125_1()
		{
			RunCompilerTestCase(@"BCE0125-1.boo");
		}
		
		[Test]
		public void BCE0126_1()
		{
			RunCompilerTestCase(@"BCE0126-1.boo");
		}
		
		[Test]
		public void BCE0126_2()
		{
			RunCompilerTestCase(@"BCE0126-2.boo");
		}
		
		[Test]
		public void BCE0126_3()
		{
			RunCompilerTestCase(@"BCE0126-3.boo");
		}
		
		[Test]
		public void BCE0126_4()
		{
			RunCompilerTestCase(@"BCE0126-4.boo");
		}
		
		[Test]
		public void BCE0126_5()
		{
			RunCompilerTestCase(@"BCE0126-5.boo");
		}
		
		[Test]
		public void BCE0127_1()
		{
			RunCompilerTestCase(@"BCE0127-1.boo");
		}
		
		[Test]
		public void BCE0128_1()
		{
			RunCompilerTestCase(@"BCE0128-1.boo");
		}
		
		[Test]
		public void BCE0129_1()
		{
			RunCompilerTestCase(@"BCE0129-1.boo");
		}
		
		[Test]
		public void BCE0130_1()
		{
			RunCompilerTestCase(@"BCE0130-1.boo");
		}
		
		[Test]
		public void BCE0131_1()
		{
			RunCompilerTestCase(@"BCE0131-1.boo");
		}
		
		[Test]
		public void BCE0131_2()
		{
			RunCompilerTestCase(@"BCE0131-2.boo");
		}
		
		[Test]
		public void BCE0132_1()
		{
			RunCompilerTestCase(@"BCE0132-1.boo");
		}
		
		[Test]
		public void BCE0132_2()
		{
			RunCompilerTestCase(@"BCE0132-2.boo");
		}
		
		[Test]
		public void BCE0132_3()
		{
			RunCompilerTestCase(@"BCE0132-3.boo");
		}
		
		[Test]
		public void BCE0132_4()
		{
			RunCompilerTestCase(@"BCE0132-4.boo");
		}
		
		[Test]
		public void BCE0132_5()
		{
			RunCompilerTestCase(@"BCE0132-5.boo");
		}
		
		[Test]
		public void BCE0133_1()
		{
			RunCompilerTestCase(@"BCE0133-1.boo");
		}
		
		[Test]
		public void BCE0133_2()
		{
			RunCompilerTestCase(@"BCE0133-2.boo");
		}
		
		[Test]
		public void BCE0134_1()
		{
			RunCompilerTestCase(@"BCE0134-1.boo");
		}
		
		[Test]
		public void BCE0134_2()
		{
			RunCompilerTestCase(@"BCE0134-2.boo");
		}
		
		[Test]
		public void BCE0136_1()
		{
			RunCompilerTestCase(@"BCE0136-1.boo");
		}
		
		[Test]
		public void BCE0137_1()
		{
			RunCompilerTestCase(@"BCE0137-1.boo");
		}
		
		[Test]
		public void BCE0137_2()
		{
			RunCompilerTestCase(@"BCE0137-2.boo");
		}
		
		[Test]
		public void BCE0137_3()
		{
			RunCompilerTestCase(@"BCE0137-3.boo");
		}
		
		[Test]
		public void BCE0141()
		{
			RunCompilerTestCase(@"BCE0141.boo");
		}
		
		[Test]
		public void BCE0142()
		{
			RunCompilerTestCase(@"BCE0142.boo");
		}
		
		[Test]
		public void BCE0143_1()
		{
			RunCompilerTestCase(@"BCE0143-1.boo");
		}
		
		[Test]
		public void BCE0145_1()
		{
			RunCompilerTestCase(@"BCE0145-1.boo");
		}
		
		[Test]
		public void BCE0150_1()
		{
			RunCompilerTestCase(@"BCE0150-1.boo");
		}
		
		[Test]
		public void BCE0151_1()
		{
			RunCompilerTestCase(@"BCE0151-1.boo");
		}
		
		[Test]
		public void BCE0151_2()
		{
			RunCompilerTestCase(@"BCE0151-2.boo");
		}
		
		[Test]
		public void BCE0152_1()
		{
			RunCompilerTestCase(@"BCE0152-1.boo");
		}
		
		[Test]
		public void BCE0153_1()
		{
			RunCompilerTestCase(@"BCE0153-1.boo");
		}
		
		[Test]
		public void BCE0153_2()
		{
			RunCompilerTestCase(@"BCE0153-2.boo");
		}
		
		[Test]
		public void BCE0154_1()
		{
			RunCompilerTestCase(@"BCE0154-1.boo");
		}
		
		[Test]
		public void BCE0154_2()
		{
			RunCompilerTestCase(@"BCE0154-2.boo");
		}
		
		[Test]
		public void BCE0155_1()
		{
			RunCompilerTestCase(@"BCE0155-1.boo");
		}
		
		[Test]
		public void BCE0156_1()
		{
			RunCompilerTestCase(@"BCE0156-1.boo");
		}
		
		[Test]
		public void BCE0157_1()
		{
			RunCompilerTestCase(@"BCE0157-1.boo");
		}
		

		override protected string GetRelativeTestCasesPath()
		{
			return "errors";
		}
	}
}
